==> muscletools_2.1.0.orig.tar.gz: muscletools-2.1.0.orig/parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     CREATE = 258,
     _DELETE = 259,
     WRITE = 260,
     READ = 261,
     LIST = 262,
     CHANGEACL = 263,
     MOVE = 264,
     CRYPT = 265,
     FILECRYPT = 266,
     RSA = 267,
     RSACRT = 268,
     DSA = 269,
     EC = 270,
     ECFP = 271,
     ECF2M = 272,
     DES = 273,
     TDES = 274,
     TDES3 = 275,
     AES = 276,
     KEYS = 277,
     PINS = 278,
     OBJECTS = 279,
     VERIFY = 280,
     MAKEPIN = 281,
     CHANGEPIN = 282,
     UNBLOCK = 283,
     LISTPINS = 284,
     DELETEID = 285,
     LISTKEYS = 286,
     EXPORTKEY = 287,
     IMPORTKEY = 288,
     GENKEYS = 289,
     DELETEKEY = 290,
     MOVEKEY = 291,
     CHANGEKEYACL = 292,
     FORMAT = 293,
     TOKENS = 294,
     CONNECT = 295,
     RESUME = 296,
     RELEASE = 297,
     STATUS = 298,
     SETSTATUS = 299,
     CHALLENGE = 300,
     LOGOUT = 301,
     _VERSION = 302,
     EXIT = 303,
     HELP = 304,
     NUMBER = 305,
     STRING = 306,
     HEXNUMBER = 307,
     SEPARATOR = 308,
     TEST = 309
   };
#endif
/* Tokens.  */
#define CREATE 258
#define _DELETE 259
#define WRITE 260
#define READ 261
#define LIST 262
#define CHANGEACL 263
#define MOVE 264
#define CRYPT 265
#define FILECRYPT 266
#define RSA 267
#define RSACRT 268
#define DSA 269
#define EC 270
#define ECFP 271
#define ECF2M 272
#define DES 273
#define TDES 274
#define TDES3 275
#define AES 276
#define KEYS 277
#define PINS 278
#define OBJECTS 279
#define VERIFY 280
#define MAKEPIN 281
#define CHANGEPIN 282
#define UNBLOCK 283
#define LISTPINS 284
#define DELETEID 285
#define LISTKEYS 286
#define EXPORTKEY 287
#define IMPORTKEY 288
#define GENKEYS 289
#define DELETEKEY 290
#define MOVEKEY 291
#define CHANGEKEYACL 292
#define FORMAT 293
#define TOKENS 294
#define CONNECT 295
#define RESUME 296
#define RELEASE 297
#define STATUS 298
#define SETSTATUS 299
#define CHALLENGE 300
#define LOGOUT 301
#define _VERSION 302
#define EXIT 303
#define HELP 304
#define NUMBER 305
#define STRING 306
#define HEXNUMBER 307
#define SEPARATOR 308
#define TEST 309




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 51 "parser.y"
typedef union YYSTYPE {
	int num;
	char *str;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 151 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> muscletools_2.1.1.orig.tar.gz: muscletools-2.1.1.orig/parser.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     CREATE = 258,
     _DELETE = 259,
     WRITE = 260,
     READ = 261,
     LIST = 262,
     CHANGEACL = 263,
     MOVE = 264,
     CRYPT = 265,
     FILECRYPT = 266,
     RSA = 267,
     RSACRT = 268,
     DSA = 269,
     EC = 270,
     ECFP = 271,
     ECF2M = 272,
     DES = 273,
     TDES = 274,
     TDES3 = 275,
     AES = 276,
     KEYS = 277,
     PINS = 278,
     OBJECTS = 279,
     VERIFY = 280,
     MAKEPIN = 281,
     CHANGEPIN = 282,
     UNBLOCK = 283,
     LISTPINS = 284,
     DELETEID = 285,
     LISTKEYS = 286,
     EXPORTKEY = 287,
     IMPORTKEY = 288,
     GENKEYS = 289,
     DELETEKEY = 290,
     MOVEKEY = 291,
     CHANGEKEYACL = 292,
     FORMAT = 293,
     TOKENS = 294,
     CONNECT = 295,
     RESUME = 296,
     RELEASE = 297,
     STATUS = 298,
     SETSTATUS = 299,
     CHALLENGE = 300,
     LOGOUT = 301,
     _VERSION = 302,
     EXIT = 303,
     HELP = 304,
     NUMBER = 305,
     STRING = 306,
     HEXNUMBER = 307,
     SEPARATOR = 308,
     TEST = 309
   };
#endif
/* Tokens.  */
#define CREATE 258
#define _DELETE 259
#define WRITE 260
#define READ 261
#define LIST 262
#define CHANGEACL 263
#define MOVE 264
#define CRYPT 265
#define FILECRYPT 266
#define RSA 267
#define RSACRT 268
#define DSA 269
#define EC 270
#define ECFP 271
#define ECF2M 272
#define DES 273
#define TDES 274
#define TDES3 275
#define AES 276
#define KEYS 277
#define PINS 278
#define OBJECTS 279
#define VERIFY 280
#define MAKEPIN 281
#define CHANGEPIN 282
#define UNBLOCK 283
#define LISTPINS 284
#define DELETEID 285
#define LISTKEYS 286
#define EXPORTKEY 287
#define IMPORTKEY 288
#define GENKEYS 289
#define DELETEKEY 290
#define MOVEKEY 291
#define CHANGEKEYACL 292
#define FORMAT 293
#define TOKENS 294
#define CONNECT 295
#define RESUME 296
#define RELEASE 297
#define STATUS 298
#define SETSTATUS 299
#define CHALLENGE 300
#define LOGOUT 301
#define _VERSION 302
#define EXIT 303
#define HELP 304
#define NUMBER 305
#define STRING 306
#define HEXNUMBER 307
#define SEPARATOR 308
#define TEST 309




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 52 "parser.y"

	int num;
	char *str;



/* Line 1676 of yacc.c  */
#line 167 "parser.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;
